@@ -12,16 +12,43 @@ class Snippet:
     """
 
     def __init__(self, input, *, header):
+        lang = ""
+        type = ""
+        props = {}
+
+        # Infer lang
+        if len(header) >= 1:
+            lang = header[0].lower()
+
+        # Infer type
+        if len(header) >= 2:
+            type = header[1].lower()
+
+        # Infer props
+        for item in header[2:]:
+            parts = item.split("=")
+            name = parts[0].lower()
+            value = parts[1].lower() if len(parts) == 2 else True
+            props[name] = value
+
+        # Set attributes
         self.__input = input
         self.__header = header
         self.__output = None
+        self.__lang = lang
+        self.__type = type
+        self.__props = props
 
+    # TODO: sync with document content/input
     def __setattr__(self, name, value):
         if name == "output":
             self.__output = value
-        # TODO: sync with document content/input
         elif name == "input":
             self.__input = value
+        elif name == "lang":
+            self.__lang = value
+        elif name == "type":
+            self.__type = value
         else:  # default setter
             super().__setattr__(name, value)
 
@@ -59,10 +86,7 @@ class Snippet:
         Returns:
             str: lang
         """
-        lang = ""
-        if len(self.__header) >= 1:
-            lang = self.__header[0].lower()
-        return lang
+        return self.__lang
 
     @property
     def type(self):
@@ -71,10 +95,7 @@ class Snippet:
         Returns:
             str: type
         """
-        type = ""
-        if len(self.__header) >= 2:
-            type = self.__header[1].lower()
-        return type
+        return self.__type
 
     @property
     def props(self):
@@ -83,13 +104,7 @@ class Snippet:
         Returns:
             dict: props
         """
-        props = {}
-        for item in self.__header[2:]:
-            parts = item.split("=")
-            name = parts[0].lower()
-            value = parts[1].lower() if len(parts) == 2 else True
-            props[name] = value
-        return props
+        return self.__props
 
     # Process
 
